@@ -48,10 +48,15 @@ int split_horizon = 1;
 unsigned short myseqno = 0;
 struct timeval seqno_time = {0, 0};
 
-extern const unsigned char v4prefix[16];
-
 #define MAX_CHANNEL_HOPS 20
 
+/* Checks whether an AE exists or must be silently ignored */
+static int
+known_ae(int ae)
+{
+    return ae <= 3;
+}
+
 /* Parse a network prefix, encoded in the somewhat baroque compressed
    representation used by Babel.  Return the number of bytes parsed. */
 static int
@@ -122,6 +127,7 @@ parse_update_subtlv(struct interface *ifp, int metric, int ae,
 {
     int type, len, i = 0;
     int channels_len;
+    int have_src_prefix = 0;
 
     /* This will be overwritten if there's a DIVERSITY_HOPS sub-TLV. */
     if(*channels_len_return < 1 || (ifp->flags & IF_FARAWAY)) {
@@ -137,8 +143,6 @@ parse_update_subtlv(struct interface *ifp, int metric, int ae,
         }
     }
 
-    *src_plen = 0;
-
     while(i < alen) {
         type = a[i];
         if(type == SUBTLV_PAD1) {
@@ -163,15 +167,17 @@ parse_update_subtlv(struct interface *ifp, int metric, int ae,
                 goto fail;
             if(a[i + 2] == 0)   /* source prefix cannot be default */
                 goto fail;
-            if(*src_plen != 0)  /* source prefix can only be specified once */
+            if(have_src_prefix != 0) /* source prefix can only appear once */
                 goto fail;
-            *src_plen = a[i + 2];
-            rc = network_prefix(ae, *src_plen, 0, a + i + 3, NULL,
+            rc = network_prefix(ae, a[i + 2], 0, a + i + 3, NULL,
                                 len - 1, src_prefix);
             if(rc < 0)
                 goto fail;
             if(ae == 1)
-                (*src_plen) += 96;
+                *src_plen = a[i + 2] + 96;
+            else
+                *src_plen = a[i + 2];
+            have_src_prefix = 1;
         } else {
             debugf("Received unknown%s Update sub-TLV %d.\n",
                    (type & 0x80) != 0 ? " mandatory" : "", type);
@@ -304,8 +310,7 @@ parse_request_subtlv(int ae, const unsigned char *a, int alen,
                      unsigned char *src_prefix, unsigned char *src_plen)
 {
     int type, len, i = 0;
-
-    *src_plen = 0;
+    int have_src_prefix = 0;
 
     while(i < alen) {
         type = a[0];
@@ -329,15 +334,17 @@ parse_request_subtlv(int ae, const unsigned char *a, int alen,
                 goto fail;
             if(a[i + 2] == 0)
                 goto fail;
-            if(*src_plen != 0)
+            if(have_src_prefix != 0)
                 goto fail;
-            *src_plen = a[i + 2];
-            rc = network_prefix(ae, *src_plen, 0, a + i + 3, NULL,
+            rc = network_prefix(ae, a[i + 2], 0, a + i + 3, NULL,
                                 len - 1, src_prefix);
             if(rc < 0)
                 goto fail;
             if(ae == 1)
-                (*src_plen) += 96;
+                *src_plen = a[i + 2] + 96;
+            else
+                *src_plen = a[i + 2];
+            have_src_prefix = 1;
         } else {
             debugf("Received unknown%s Route Request sub-TLV %d.\n",
                    ((type & 0x80) != 0) ? " mandatory" : "", type);
@@ -571,6 +578,11 @@ parse_packet(const unsigned char *from, struct interface *ifp,
             unsigned char address[16];
             int rc;
             if(len < 6) goto fail;
+            if(!known_ae(message[2])) {
+                debugf("Received IHU with unknown AE %d. Ignoring.\n",
+                       message[2]);
+                goto done;
+            }
             DO_NTOHS(txcost, message + 4);
             DO_NTOHS(interval, message + 6);
             rc = network_address(message[2], message + 8, len - 6, address);
@@ -616,8 +628,16 @@ parse_packet(const unsigned char *from, struct interface *ifp,
                 have_v6_nh = 0;
                 goto fail;
             }
-            rc = network_address(message[2], message + 4, len - 2,
-                                 nh);
+            rc = network_address(message[2], message + 4, len - 2, nh);
+            if(!known_ae(message[2])) {
+                debugf("Received NH with unknown AE %d. Ignoring.\n",
+                       message[2]);
+                goto done;
+            }
+            if(message[2] == 0) {
+                debugf("Received NH with bad AE 0. Error.\n");
+                goto fail;
+            }
             if(rc < 0) {
                 have_v4_nh = 0;
                 have_v6_nh = 0;
@@ -648,6 +668,11 @@ parse_packet(const unsigned char *from, struct interface *ifp,
                     have_v4_prefix = have_v6_prefix = 0;
                 goto fail;
             }
+            if(!known_ae(message[2])) {
+                debugf("Received update with unknown AE %d. Ignoring.\n",
+                       message[2]);
+                goto done;
+            }
             DO_NTOHS(interval, message + 6);
             DO_NTOHS(seqno, message + 8);
             DO_NTOHS(metric, message + 10);
@@ -755,6 +780,11 @@ parse_packet(const unsigned char *from, struct interface *ifp,
             unsigned char prefix[16], src_prefix[16], plen, src_plen;
             int rc, is_ss;
             if(len < 2) goto fail;
+            if(!known_ae(message[2])) {
+                debugf("Received request with unknown AE %d. Ignoring.\n",
+                       message[2]);
+                goto done;
+            }
             rc = network_prefix(message[2], message[3], 0,
                                 message + 4, NULL, len - 2, prefix);
             if(rc < 0) goto fail;
@@ -804,6 +834,11 @@ parse_packet(const unsigned char *from, struct interface *ifp,
             unsigned short seqno;
             int rc, is_ss;
             if(len < 14) goto fail;
+            if(!known_ae(message[2])) {
+                debugf("Received mh_request with unknown AE %d. Ignoring.\n",
+                       message[2]);
+                goto done;
+            }
             DO_NTOHS(seqno, message + 4);
             rc = network_prefix(message[2], message[3], 0,
                                 message + 16, NULL, len - 14, prefix);
